Struct SharedCounterData
Source struct SharedCounterData {
state: Mutex<CounterState>,
read_waker: Waker,
write_waker: Waker,
}
Shared counter data including state and wakers
Waker for tasks waiting to read
Waker for tasks waiting to write
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
[From]<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.